============================
Salt 2016.11.8 Release Notes
============================

Version 2016.11.8 is a bugfix release for :ref:`2016.11.0 <release-2016-11-0>`.]

Changes for v2016.11.7..v2016.11.8
----------------------------------

Extended changelog courtesy of Todd Stansell (https://github.com/tjstansell/salt-changelogs):

*Generated at: 2017-09-11T14:52:27Z*

Statistics:

- Total Merges: **169**
- Total Issue references: **70**
- Total PR references: **206**

Changes:


- **PR** `#43271`_: (*twangboy*) Fix minor formatting issue
  @ *2017-08-30T18:35:12Z*

  * cf21f91 Merge pull request `#43271`_ from twangboy/win_fix_pkg.install
  * 91b062f Fix formatting issue, spaces surrounding +

- **PR** `#43228`_: (*twangboy*) Win fix pkg.install
  @ *2017-08-30T14:26:21Z*

  * 3a0b02f Merge pull request `#43228`_ from twangboy/win_fix_pkg.install
  * 13dfabb Fix regex statement, add `.`

  * 31ff69f Add underscore to regex search

  * 3cf2b65 Fix spelling

  * ed030a3 Use regex to detect salt-minion install

  * e5daff4 Fix pkg.install

- **PR** `#43191`_: (*viktorkrivak*) Fix apache.config with multiple statement
  @ *2017-08-28T18:13:44Z*

  * b4c689d Merge pull request `#43191`_ from viktorkrivak/fix-apache-config-multi-entity
  * c15bcbe Merge remote-tracking branch 'upstream/2016.11' into fix-apache-config-multi-entity

  * 4164047 Fix apache.config with multiple statement At this moment when you post more than one statement in config only last is used. Also file is rewrited multiple times until last statement is written. Example: salt '*' apache.config /etc/httpd/conf.d/ports.conf config="[{'Listen': '8080'}, {'Proxy': "Something"}]" Ends only with    Proxy Something and ignore Listen 8080, This patch fix this issue.

- **PR** `#43154`_: (*lomeroe*) Backport `#43116`_ to 2016.11
  @ *2017-08-28T16:40:41Z*

  - **ISSUE** `#42279`_: (*dafyddj*) win_lgpo matches multiple policies due to startswith()
    | refs: `#43116`_ `#43116`_ `#43154`_
  - **PR** `#43116`_: (*lomeroe*) Fix 42279 in develop
    | refs: `#43154`_
  * b90e59e Merge pull request `#43154`_ from lomeroe/`bp-43116`_-2016.11
  * 8f593b0 verify that files exist before trying to remove them, win_file.remove raises an exception if the file does not exist

  * 33a30ba correcting bad format statement in search for policy to be disabled

  * acc3d7a correct fopen calls from salt.utils for 2016.11's utils function

  * 2da1cdd lint fix

  * 61bd12c track xml namespace to ensure policies w/duplicate IDs or Names do not conflict

  * f232bed add additional checks for ADM policies that have the same ADMX policy ID (`#42279`_)

- **PR** `#43202`_: (*garethgreenaway*) Reverting previous augeas module changes
  @ *2017-08-28T13:14:27Z*

  - **ISSUE** `#42642`_: (*githubcdr*) state.augeas
    | refs: `#42669`_ `#43202`_
  * 5308c27 Merge pull request `#43202`_ from garethgreenaway/42642_2016_11_augeas_module_revert_fix
  * ef7e93e Reverting this change due to it breaking other uses.

- **PR** `#43103`_: (*aogier*) genesis.bootstrap deboostrap fix
  @ *2017-08-25T20:48:23Z*

  - **ISSUE** `#43101`_: (*aogier*) genesis.bootstrap fails if no pkg AND exclude_pkgs (which can't be a string)
    | refs: `#43103`_
  * f16b724 Merge pull request `#43103`_ from aogier/43101-genesis-bootstrap
  * db94f3b better formatting

  * e5cc667 tests: fix a leftover and simplify some parts

  * 13e5997 lint

  * 216ced6 allow comma-separated pkgs lists, quote args, test deb behaviour

  * d8612ae fix debootstrap and enhance packages selection/deletion via cmdline

- **PR** `#42663`_: (*jagguli*) Check remote tags before deciding to do a fetch `#42329`_
  @ *2017-08-25T20:14:32Z*

  - **ISSUE** `#42329`_: (*jagguli*) State git.latest does not pull latest tags
    | refs: `#42663`_
  * 4863771 Merge pull request `#42663`_ from StreetHawkInc/fix_git_tag_check
  * 2b5af5b Remove refs/tags prefix from remote tags

  * 3f2e96e Convert set to list for serializer

  * 2728e5d Only include new tags in changes

  * 4b1df2f Exclude annotated tags from checks

  * 389c037 Check remote tags before deciding to do a fetch `#42329`_

- **PR** `#43199`_: (*corywright*) Add `disk.format` alias for `disk.format_`
  @ *2017-08-25T19:21:07Z*

  - **ISSUE** `#43198`_: (*corywright*) disk.format_ needs to be aliased to disk.format
    | refs: `#43199`_
  * 4193e7f Merge pull request `#43199`_ from corywright/disk-format-alias
  * f00d3a9 Add `disk.format` alias for `disk.format_`

- **PR** `#43196`_: (*gtmanfred*) Pin request install to version for npm tests
  @ *2017-08-25T18:43:06Z*

  - **ISSUE** `#495`_: (*syphernl*) mysql.* without having MySQL installed/configured gives traceback
    | refs: `#43196`_
  * 5471f9f Merge pull request `#43196`_ from gtmanfred/2016.11
  * ccd2241 Pin request install to version

- **PR** `#43178`_: (*terminalmage*) git.detached: Fix traceback when rev is a SHA and is not present locally
  @ *2017-08-25T13:58:37Z*

  - **ISSUE** `#43143`_: (*abulford*) git.detached does not fetch if rev is missing from local
    | refs: `#43178`_
  * ace2715 Merge pull request `#43178`_ from terminalmage/issue43143
  * 2640833 git.detached: Fix traceback when rev is a SHA and is not present locally

- **PR** `#43179`_: (*terminalmage*) Fix missed deprecation
  @ *2017-08-24T22:52:34Z*

  * 12e9507 Merge pull request `#43179`_ from terminalmage/old-deprecation
  * 3adf8ad Fix missed deprecation

- **PR** `#43171`_: (*terminalmage*) Add warning about adding new functions to salt/utils/__init__.py
  @ *2017-08-24T19:10:23Z*

  * b595440 Merge pull request `#43171`_ from terminalmage/salt-utils-warning
  * 7b5943a Add warning about adding new functions to salt/utils/__init__.py

- **PR** `#43173`_: (*Ch3LL*) Add New Release Branch Strategy to Contribution Docs
  @ *2017-08-24T19:04:56Z*

  * 4f273ca Merge pull request `#43173`_ from Ch3LL/add_branch_docs
  * 1b24244 Add New Release Branch Strategy to Contribution Docs

- **PR** `#43151`_: (*ushmodin*) state.sls hangs on file.recurse with clean: True on windows
  @ *2017-08-23T17:25:33Z*

  - **PR** `#42969`_: (*ushmodin*) state.sls hangs on file.recurse with clean: True on windows
    | refs: `#43151`_
  * 669b376 Merge pull request `#43151`_ from ushmodin/2016.11
  * c5841e2 state.sls hangs on file.recurse with clean: True on windows

- **PR** `#42986`_: (*renner*) Notify systemd synchronously (via NOTIFY_SOCKET)
  @ *2017-08-22T16:52:56Z*

  * ae9d2b7 Merge pull request `#42986`_ from renner/systemd-notify
  * 79c53f3 Fallback to systemd_notify_call() in case of socket.error

  * f176547 Notify systemd synchronously (via NOTIFY_SOCKET)

- **PR** `#43037`_: (*mcarlton00*) Issue `#43036`_ Bhyve virtual grain in Linux VMs
  @ *2017-08-22T16:43:40Z*

  - **ISSUE** `#43036`_: (*mcarlton00*) Linux VMs in Bhyve aren't displayed properly in grains
    | refs: `#43037`_
  * b420fbe Merge pull request `#43037`_ from mcarlton00/fix-bhyve-grains
  * 73315f0 Issue `#43036`_ Bhyve virtual grain in Linux VMs

- **PR** `#43100`_: (*vutny*) [DOCS] Add missing `utils` sub-dir listed for `extension_modules`
  @ *2017-08-22T15:40:09Z*

  * 0a86f2d Merge pull request `#43100`_ from vutny/doc-add-missing-utils-ext
  * af743ff [DOCS] Add missing `utils` sub-dir listed for `extension_modules`

- **PR** `#42985`_: (*DmitryKuzmenko*) Properly handle `prereq` having lost requisites.
  @ *2017-08-21T22:49:39Z*

  - **ISSUE** `#15171`_: (*JensRantil*) Maximum recursion limit hit related to requisites
    | refs: `#42985`_
  * e2bf2f4 Merge pull request `#42985`_ from DSRCorporation/bugs/15171_recursion_limit
  * 651b1ba Properly handle `prereq` having lost requisites.

- **PR** `#43092`_: (*blarghmatey*) Fixed issue with silently passing all tests in Testinfra module
  @ *2017-08-21T20:22:08Z*

  * e513333 Merge pull request `#43092`_ from mitodl/2016.11
  * d4b113a Fixed issue with silently passing all tests in Testinfra module

- **PR** `#43060`_: (*twangboy*) Osx update pkg scripts
  @ *2017-08-21T20:06:12Z*

  * 77a443c Merge pull request `#43060`_ from twangboy/osx_update_pkg_scripts
  * ef8a14c Remove /opt/salt instead of /opt/salt/bin

  * 2dd62aa Add more information to the description

  * f44f5b7 Only stop services if they are running

  * 3b62bf9 Remove salt from the path

  * ebdca3a Update pkg-scripts

- **PR** `#43064`_: (*terminalmage*) Fix race condition in git.latest
  @ *2017-08-21T14:29:52Z*

  - **ISSUE** `#42869`_: (*abednarik*) Git Module : Failed to update repository
    | refs: `#43064`_
  * 1b1b6da Merge pull request `#43064`_ from terminalmage/issue42869
  * 093c0c2 Fix race condition in git.latest

- **PR** `#43054`_: (*lorengordon*) Uses ConfigParser to read yum config files
  @ *2017-08-18T20:49:44Z*

  - **ISSUE** `#42041`_: (*lorengordon*) pkg.list_repo_pkgs fails to find pkgs with spaces around yum repo enabled value
    | refs: `#43054`_
  - **PR** `#42045`_: (*arount*) Fix: salt.modules.yumpkg: ConfigParser to read ini like files.
    | refs: `#43054`_
  * 96e8e83 Merge pull request `#43054`_ from lorengordon/fix/yumpkg/config-parser
  * 3b2cb81 fix typo in salt.modules.yumpkg

  * 38add0e break if leading comments are all fetched

  * d7f65dc fix configparser import & log if error was raised

  * ca1b1bb use configparser to parse yum repo file

- **PR** `#43048`_: (*rallytime*) Back-port `#43031`_ to 2016.11
  @ *2017-08-18T12:56:04Z*

  - **PR** `#43031`_: (*gtmanfred*) use a ruby gem that doesn't have dependencies
    | refs: `#43048`_
  * 43aa46f Merge pull request `#43048`_ from rallytime/`bp-43031`_
  * 35e4504 use a ruby gem that doesn't have dependencies

- **PR** `#43023`_: (*terminalmage*) Fixes/improvements to Jenkins state/module
  @ *2017-08-18T01:33:10Z*

  * ad89ff3 Merge pull request `#43023`_ from terminalmage/fix-jenkins-xml-caching
  * 33fd8ff Update jenkins.py

  * fc306fc Add missing colon in `if` statement

  * 822eabc Catch exceptions raised when making changes to jenkins

  * 91b583b Improve and correct execption raising

  * f096917 Raise an exception if we fail to cache the config xml

- **PR** `#43026`_: (*rallytime*) Back-port `#43020`_ to 2016.11
  @ *2017-08-17T23:19:46Z*

  - **PR** `#43020`_: (*gtmanfred*) test with gem that appears to be abandoned
    | refs: `#43026`_
  * 2957467 Merge pull request `#43026`_ from rallytime/`bp-43020`_
  * 0eb15a1 test with gem that appears to be abandoned

- **PR** `#43033`_: (*rallytime*) Back-port `#42760`_ to 2016.11
  @ *2017-08-17T22:24:43Z*

  - **ISSUE** `#40490`_: (*alxwr*) saltstack x509 incompatible to m2crypto 0.26.0
    | refs: `#42760`_
  - **PR** `#42760`_: (*AFriemann*) Catch TypeError thrown by m2crypto when parsing missing subjects in c…
    | refs: `#43033`_
  * 4150b09 Merge pull request `#43033`_ from rallytime/`bp-42760`_
  * 3e3f7f5 Catch TypeError thrown by m2crypto when parsing missing subjects in certificate files.

- **PR** `#43032`_: (*rallytime*) Back-port `#42547`_ to 2016.11
  @ *2017-08-17T21:53:50Z*

  - **PR** `#42547`_: (*blarghmatey*) Updated testinfra modules to work with more recent versions
    | refs: `#43032`_
  * b124d36 Merge pull request `#43032`_ from rallytime/`bp-42547`_
  * ea4d7f4 Updated testinfra modules to work with more recent versions

- **PR** `#43027`_: (*pabloh007*) Fixes ignore push flag for docker.push module issue `#42992`_
  @ *2017-08-17T19:55:37Z*

  - **ISSUE** `#42992`_: (*pabloh007*) docker.save  flag push does is ignored
  * a88386a Merge pull request `#43027`_ from pabloh007/fix-docker-save-push-2016-11
  * d0fd949 Fixes ignore push flag for docker.push module issue `#42992`_

- **PR** `#42890`_: (*DmitryKuzmenko*) Make chunked mode in salt-cp optional
  @ *2017-08-17T18:37:44Z*

  - **ISSUE** `#42627`_: (*taigrrr8*) salt-cp no longer works.  Was working a few months back.
    | refs: `#42890`_
  * 51d1684 Merge pull request `#42890`_ from DSRCorporation/bugs/42627_salt-cp
  * cfddbf1 Apply code review: update the doc

  * afedd3b Typos and version fixes in the doc.

  * 9fedf60 Fixed 'test_valid_docs' test.

  * 9993886 Make chunked mode in salt-cp optional (disabled by default).

- **PR** `#43009`_: (*rallytime*) [2016.11] Merge forward from 2016.3 to 2016.11
  @ *2017-08-17T18:00:09Z*

  - **PR** `#42954`_: (*Ch3LL*) [2016.3] Bump latest and previous versions
  - **PR** `#42949`_: (*Ch3LL*) Add Security Notice to 2016.3.7 Release Notes
  - **PR** `#42942`_: (*Ch3LL*) [2016.3] Add clean_id function to salt.utils.verify.py
  * b3c253c Merge pull request `#43009`_ from rallytime/merge-2016.11
  * 566ba4f Merge branch '2016.3' into '2016.11'

    * 13b8637 Merge pull request `#42942`_ from Ch3LL/2016.3.6_follow_up

      * f281e17 move additional minion config options to 2016.3.8 release notes

      * 168604b remove merge conflict

      * 8a07d95 update release notes with cve number

      * 149633f Add release notes for 2016.3.7 release

      * 7a4cddc Add clean_id function to salt.utils.verify.py

    * bbb1b29 Merge pull request `#42954`_ from Ch3LL/latest_2016.3

      * b551e66 [2016.3] Bump latest and previous versions

    * 5d5edc5 Merge pull request `#42949`_ from Ch3LL/2016.3.7_docs

      * d75d374 Add Security Notice to 2016.3.7 Release Notes

- **PR** `#43021`_: (*terminalmage*) Use socket.AF_INET6 to get the correct value instead of doing an OS check
  @ *2017-08-17T17:57:09Z*

  - **PR** `#43014`_: (*Ch3LL*) Change AF_INET6 family for mac in test_host_to_ips
    | refs: `#43021`_
  * 37c63e7 Merge pull request `#43021`_ from terminalmage/fix-network-test
  * 4089b7b Use socket.AF_INET6 to get the correct value instead of doing an OS check

- **PR** `#43019`_: (*rallytime*) Update bootstrap script to latest stable: v2017.08.17
  @ *2017-08-17T17:56:41Z*

  * 8f64232 Merge pull request `#43019`_ from rallytime/bootstrap_2017.08.17
  * 2f762b3 Update bootstrap script to latest stable: v2017.08.17

- **PR** `#43014`_: (*Ch3LL*) Change AF_INET6 family for mac in test_host_to_ips
  | refs: `#43021`_
  @ *2017-08-17T16:17:51Z*

  * ff1caeee Merge pull request `#43014`_ from Ch3LL/fix_network_mac
  * b8eee44 Change AF_INET6 family for mac in test_host_to_ips

- **PR** `#42968`_: (*vutny*) [DOCS] Fix link to Salt Cloud Feature Matrix
  @ *2017-08-16T13:16:16Z*

  * 1ee9499 Merge pull request `#42968`_ from vutny/doc-salt-cloud-ref
  * 44ed53b [DOCS] Fix link to Salt Cloud Feature Matrix

- **PR** `#42291`_: (*vutny*) Fix `#38839`_: remove `state` from Reactor runner kwags
  @ *2017-08-15T23:01:08Z*

  - **ISSUE** `#38839`_: (*DaveOHenry*) Invoking runner.cloud.action via reactor sls fails
    | refs: `#42291`_
  * 923f974 Merge pull request `#42291`_ from vutny/`fix-38839`_
  * 5f8f98a Fix `#38839`_: remove `state` from Reactor runner kwags

- **PR** `#42940`_: (*gtmanfred*) create new ip address before checking list of allocated ips
  @ *2017-08-15T21:47:18Z*

  - **ISSUE** `#42644`_: (*stamak*)   nova salt-cloud -P  Private IPs returned, but not public. Checking for misidentified IPs
    | refs: `#42940`_
  * c20bc7d Merge pull request `#42940`_ from gtmanfred/2016.11
  * 253e216 fix IP address spelling

  * bd63074 create new ip address before checking list of allocated ips

- **PR** `#42959`_: (*rallytime*) Back-port `#42883`_ to 2016.11
  @ *2017-08-15T21:25:48Z*

  - **PR** `#42883`_: (*rallytime*) Fix failing boto tests
    | refs: `#42959`_
  * d6496ec Merge pull request `#42959`_ from rallytime/`bp-42883`_
  * c6b9ca4 Lint fix: add missing space

  * 5597b1a Skip 2 failing tests in Python 3 due to upstream bugs

  * a0b19bd Update account id value in boto_secgroup module unit test

  * 60b406e @mock_elb needs to be changed to @mock_elb_deprecated as well

  * 6ae1111 Replace @mock_ec2 calls with @mock_ec2_deprecated calls

- **PR** `#42944`_: (*Ch3LL*) [2016.11] Add clean_id function to salt.utils.verify.py
  @ *2017-08-15T18:06:12Z*

  * 6366e05 Merge pull request `#42944`_ from Ch3LL/2016.11.6_follow_up
  * 7e0a20a Add release notes for 2016.11.7 release

  * 63823f8 Add clean_id function to salt.utils.verify.py

- **PR** `#42952`_: (*Ch3LL*) [2016.11] Bump latest and previous versions
  @ *2017-08-15T17:23:02Z*

  * 49d339c Merge pull request `#42952`_ from Ch3LL/latest_2016.11
  * 74e7055 [2016.11] Bump latest and previous versions

- **PR** `#42950`_: (*Ch3LL*) Add Security Notice to 2016.11.7 Release Notes
  @ *2017-08-15T16:50:23Z*

  * b0d2e05 Merge pull request `#42950`_ from Ch3LL/2016.11.7_docs
  * a6f902d Add Security Notice to 2016.11.77 Release Notes

- **PR** `#42836`_: (*aneeshusa*) Backport salt.utils.versions from develop to 2016.11
  @ *2017-08-14T20:56:54Z*

  - **PR** `#42835`_: (*aneeshusa*) Fix typo in utils/versions.py module
    | refs: `#42836`_
  * c0ff69f Merge pull request `#42836`_ from lyft/backport-utils.versions-to-2016.11
  * 86ce700 Backport salt.utils.versions from develop to 2016.11

- **PR** `#42919`_: (*rallytime*) Back-port `#42871`_ to 2016.11
  @ *2017-08-14T20:44:00Z*

  - **PR** `#42871`_: (*amalleo25*) Update joyent.rst
    | refs: `#42919`_
  * 64a79dd Merge pull request `#42919`_ from rallytime/`bp-42871`_
  * 4e46c96 Update joyent.rst

- **PR** `#42918`_: (*rallytime*) Back-port `#42848`_ to 2016.11
  @ *2017-08-14T20:43:43Z*

  - **ISSUE** `#42803`_: (*gmcwhistler*) master_type: str, not working as expected, parent salt-minion process dies.
    | refs: `#42848`_
  - **ISSUE** `#42753`_: (*grichmond-salt*) SaltReqTimeout Error on Some Minions when One Master in a Multi-Master Configuration is Unavailable
    | refs: `#42848`_
  - **PR** `#42848`_: (*DmitryKuzmenko*) Execute fire_master asynchronously in the main minion thread.
    | refs: `#42918`_
  * bea8ec1 Merge pull request `#42918`_ from rallytime/`bp-42848`_
  * cdb4812 Make lint happier.

  * 62eca9b Execute fire_master asynchronously in the main minion thread.

- **PR** `#42861`_: (*twangboy*) Fix pkg.install salt-minion using salt-call
  @ *2017-08-14T19:07:22Z*

  * 52bce32 Merge pull request `#42861`_ from twangboy/win_pkg_install_salt
  * 0d3789f Fix pkg.install salt-minion using salt-call

- **PR** `#42798`_: (*s-sebastian*) Update return data before calling returners
  @ *2017-08-14T15:51:30Z*

  * b9f4f87 Merge pull request `#42798`_ from s-sebastian/2016.11
  * 1cc8659 Update return data before calling returners

- **PR** `#41977`_: (*abulford*) Fix dockerng.network_* ignoring of tests=True
  @ *2017-08-11T18:37:20Z*

  - **ISSUE** `#41976`_: (*abulford*) dockerng network states do not respect test=True
    | refs: `#41977`_ `#41977`_
  * c15d003 Merge pull request `#41977`_ from redmatter/fix-dockerng-network-ignores-test
  * 1cc2aa5 Fix dockerng.network_* ignoring of tests=True

- **PR** `#42886`_: (*sarcasticadmin*) Adding missing output flags to salt cli docs
  @ *2017-08-11T18:35:19Z*

  * 3b9c3c5 Merge pull request `#42886`_ from sarcasticadmin/adding_docs_salt_outputs
  * 744bf95 Adding missing output flags to salt cli

- **PR** `#42882`_: (*gtmanfred*) make sure cmd is not run when npm isn't installed
  @ *2017-08-11T17:53:14Z*

  * e5b98c8 Merge pull request `#42882`_ from gtmanfred/2016.11
  * da3402a make sure cmd is not run when npm isn't installed

- **PR** `#42788`_: (*amendlik*) Remove waits and retries from Saltify deployment
  @ *2017-08-11T15:38:05Z*

  * 5962c95 Merge pull request `#42788`_ from amendlik/saltify-timeout
  * 928b523 Remove waits and retries from Saltify deployment

- **PR** `#42877`_: (*terminalmage*) Add virtual func for cron state module
  @ *2017-08-11T15:33:09Z*

  * 227ecdd Merge pull request `#42877`_ from terminalmage/add-cron-state-virtual
  * f1de196 Add virtual func for cron state module

- **PR** `#42859`_: (*terminalmage*) Add note about git CLI requirement for GitPython to GitFS tutorial
  @ *2017-08-11T14:53:03Z*

  * ab9f6ce Merge pull request `#42859`_ from terminalmage/gitpython-git-cli-note
  * 35e05c9 Add note about git CLI requirement for GitPython to GitFS tutorial

- **PR** `#42856`_: (*gtmanfred*) skip cache_clean test if npm version is >= 5.0.0
  @ *2017-08-11T13:39:20Z*

  - **ISSUE** `#41770`_: (*Ch3LL*) NPM v5 incompatible with salt.modules.cache_list
    | refs: `#42856`_
  - **ISSUE** `#475`_: (*thatch45*) Change yaml to use C bindings
    | refs: `#42856`_
  * 682b4a8 Merge pull request `#42856`_ from gtmanfred/2016.11
  * b458b89 skip cache_clean test if npm version is >= 5.0.0

- **PR** `#42864`_: (*whiteinge*) Make syndic_log_file respect root_dir setting
  @ *2017-08-11T13:28:21Z*

  * 01ea854 Merge pull request `#42864`_ from whiteinge/syndic-log-root_dir
  * 4b1f55d Make syndic_log_file respect root_dir setting

- **PR** `#42851`_: (*terminalmage*) Backport `#42651`_ to 2016.11
  @ *2017-08-10T18:02:39Z*

  - **PR** `#42651`_: (*gtmanfred*) python2- prefix for fedora 26 packages
  * 2dde1f7 Merge pull request `#42851`_ from terminalmage/`bp-42651`_
  * a3da86e fix syntax

  * 6ecdbce make sure names are correct

  * f83b553 add py3 for versionlock

  * 21934f6 python2- prefix for fedora 26 packages

- **PR** `#42806`_: (*rallytime*) Update doc references in glusterfs.volume_present
  @ *2017-08-10T14:10:16Z*

  - **ISSUE** `#42683`_: (*rgcosma*) Gluster module broken in 2017.7
    | refs: `#42806`_
  * c746f79 Merge pull request `#42806`_ from rallytime/`fix-42683`_
  * 8c8640d Update doc references in glusterfs.volume_present

- **PR** `#42829`_: (*twangboy*) Fix passing version in pkgs as shown in docs
  @ *2017-08-10T14:07:24Z*

  * 27a8a26 Merge pull request `#42829`_ from twangboy/win_pkg_fix_install
  * 83b9b23 Add winrepo to docs about supporting versions in pkgs

  * 81fefa6 Add ability to pass version in pkgs list

- **PR** `#42838`_: (*twangboy*) Document requirements for win_pki
  @ *2017-08-10T13:59:46Z*

  * 3c3ac6a Merge pull request `#42838`_ from twangboy/win_doc_pki
  * f0a1d06 Standardize PKI Client

  * 7de687a Document requirements for win_pki

- **PR** `#42805`_: (*rallytime*) Back-port `#42552`_ to 2016.11
  @ *2017-08-09T22:37:56Z*

  - **PR** `#42552`_: (*remijouannet*) update consul module following this documentation https://www.consul.…
    | refs: `#42805`_
  * b3e2ae3 Merge pull request `#42805`_ from rallytime/`bp-42552`_
  * 5a91c1f update consul module following this documentation https://www.consul.io/api/acl.html

- **PR** `#42804`_: (*rallytime*) Back-port `#42784`_ to 2016.11
  @ *2017-08-09T22:37:40Z*

  - **ISSUE** `#42731`_: (*infoveinx*) http.query template_data render exception
    | refs: `#42804`_
  - **PR** `#42784`_: (*gtmanfred*) only read file if ret is not a string in http.query
    | refs: `#42804`_
  * d2ee793 Merge pull request `#42804`_ from rallytime/`bp-42784`_
  * dbd29e4 only read file if it is not a string

- **PR** `#42826`_: (*terminalmage*) Fix misspelling of "versions"
  @ *2017-08-09T19:39:43Z*

  * 4cbf805 Merge pull request `#42826`_ from terminalmage/fix-spelling
  * 00f9314 Fix misspelling of "versions"

- **PR** `#42786`_: (*Ch3LL*) Fix typo for template_dict in http docs
  @ *2017-08-08T18:14:50Z*

  * de997ed Merge pull request `#42786`_ from Ch3LL/fix_typo
  * 90a2fb6 Fix typo for template_dict in http docs

- **PR** `#42795`_: (*lomeroe*) backport `#42744`_ to 2016.11
  @ *2017-08-08T17:17:15Z*

  - **ISSUE** `#42600`_: (*twangboy*) Unable to set 'Not Configured' using win_lgpo execution module
    | refs: `#42744`_ `#42795`_
  - **PR** `#42744`_: (*lomeroe*) fix `#42600`_ in develop
    | refs: `#42795`_
  * bf6153e Merge pull request `#42795`_ from lomeroe/`bp-42744`__201611
  * 695f8c1 fix `#42600`_ in develop

- **PR** `#42748`_: (*whiteinge*) Workaround Orchestrate problem that highstate outputter mutates data
  @ *2017-08-07T21:11:33Z*

  - **ISSUE** `#42747`_: (*whiteinge*) Outputters mutate data which can be a problem for Runners and perhaps other things
    | refs: `#42748`_
  * 61fad97 Merge pull request `#42748`_ from whiteinge/save-before-output
  * de60b77 Workaround Orchestrate problem that highstate outputter mutates data

- **PR** `#42764`_: (*amendlik*) Fix infinite loop with salt-cloud and Windows nodes
  @ *2017-08-07T20:47:07Z*

  * a4e3e7e Merge pull request `#42764`_ from amendlik/cloud-win-loop
  * f3dcfca Fix infinite loops on failed Windows deployments

- **PR** `#42694`_: (*gtmanfred*) allow adding extra remotes to a repository
  @ *2017-08-07T18:08:11Z*

  - **ISSUE** `#42690`_: (*ChristianBeer*) git.latest state with remote set fails on first try
    | refs: `#42694`_
  * da85326 Merge pull request `#42694`_ from gtmanfred/2016.11
  * 1a0457a allow adding extra remotes to a repository

- **PR** `#42669`_: (*garethgreenaway*)  [2016.11] Fixes to augeas module
  @ *2017-08-06T17:58:03Z*

  - **ISSUE** `#42642`_: (*githubcdr*) state.augeas
    | refs: `#42669`_ `#43202`_
  * 7b2119f Merge pull request `#42669`_ from garethgreenaway/42642_2016_11_augeas_module_fix
  * 2441308 Updating the call to shlex_split to pass the posix=False argument so that quotes are preserved.

- **PR** `#42629`_: (*xiaoanyunfei*) tornado api
  @ *2017-08-03T22:21:20Z*

  * 3072576 Merge pull request `#42629`_ from xiaoanyunfei/tornadoapi
  * 1e13383 tornado api

- **PR** `#42655`_: (*whiteinge*) Reenable cpstats for rest_cherrypy
  @ *2017-08-03T20:44:10Z*

  - **PR** `#33806`_: (*cachedout*) Work around upstream cherrypy bug
    | refs: `#42655`_
  * f0f00fc Merge pull request `#42655`_ from whiteinge/rest_cherrypy-reenable-stats
  * deb6316 Fix lint errors

  * 6bd91c8 Reenable cpstats for rest_cherrypy

- **PR** `#42693`_: (*gilbsgilbs*) Fix RabbitMQ tags not properly set.
  @ *2017-08-03T20:23:08Z*

  - **ISSUE** `#42686`_: (*gilbsgilbs*) Unable to set multiple RabbitMQ tags
    | refs: `#42693`_ `#42693`_
  * 21cf15f Merge pull request `#42693`_ from gilbsgilbs/fix-rabbitmq-tags
  * 78fccdc Cast to list in case tags is a tuple.

  * 287b57b Fix RabbitMQ tags not properly set.

- **PR** `#42574`_: (*sbojarski*) Fixed error reporting in "boto_cfn.present" function.
  @ *2017-08-01T17:55:29Z*

  - **ISSUE** `#41433`_: (*sbojarski*) boto_cfn.present fails when reporting error for failed state
    | refs: `#42574`_
  * f2b0c9b Merge pull request `#42574`_ from sbojarski/boto-cfn-error-reporting
  * 5c945f1 Fix debug message in "boto_cfn._validate" function.

  * 181a1be Fixed error reporting in "boto_cfn.present" function.

- **PR** `#42623`_: (*terminalmage*) Fix unicode constructor in custom YAML loader
  @ *2017-07-31T19:25:18Z*

  * bc1effc Merge pull request `#42623`_ from terminalmage/fix-unicode-constructor
  * fcf4588 Fix unicode constructor in custom YAML loader

- **PR** `#42515`_: (*gtmanfred*) Allow not interpreting backslashes in the repl
  @ *2017-07-28T16:00:09Z*

  * cbf752c Merge pull request `#42515`_ from gtmanfred/backslash
  * cc4e456 Allow not interpreting backslashes in the repl

- **PR** `#42586`_: (*gdubroeucq*) [Fix] yumpkg.py: add option to the command "check-update"
  @ *2017-07-27T23:52:00Z*

  - **ISSUE** `#42456`_: (*gdubroeucq*) Use yum lib 
    | refs: `#42586`_
  * 5494958 Merge pull request `#42586`_ from gdubroeucq/2016.11
  * 9c0b5cc Remove extra newline

  * d2ef448 yumpkg.py: clean

  * a96f7c0 yumpkg.py: add option to the command "check-update"

- **PR** `#41988`_: (*abulford*) Fix dockerng.network_* name matching
  @ *2017-07-27T21:25:06Z*

  - **ISSUE** `#41982`_: (*abulford*) dockerng.network_* matches too easily
    | refs: `#41988`_ `#41988`_
  * 6b45deb Merge pull request `#41988`_ from redmatter/fix-dockerng-network-matching
  * 9eea796 Add regression tests for `#41982`_

  * 3369f00 Fix broken unit test test_network_absent

  * 0ef6cf6 Add trace logging of dockerng.networks result

  * 515c612 Fix dockerng.network_* name matching

- **PR** `#42339`_: (*isbm*) Bugfix: Jobs scheduled to run at a future time stay pending for Salt minions (bsc`#1036125`_)
  @ *2017-07-27T19:05:51Z*

  - **ISSUE** `#1036125`_: (**) 
  * 4b16109 Merge pull request `#42339`_ from isbm/isbm-jobs-scheduled-in-a-future-bsc1036125
  * bbba84c Bugfix: Jobs scheduled to run at a future time stay pending for Salt minions (bsc`#1036125`_)

- **PR** `#42077`_: (*vutny*) Fix scheduled job run on Master if `when` parameter is a list
  @ *2017-07-27T19:04:23Z*

  - **ISSUE** `#23516`_: (*dkiser*) BUG: cron job scheduler sporadically works
    | refs: `#42077`_
  - **PR** `#41973`_: (*vutny*) Fix Master/Minion scheduled jobs based on Cron expressions
    | refs: `#42077`_
  * 6c5a7c6 Merge pull request `#42077`_ from vutny/fix-jobs-scheduled-with-whens
  * b1960ce Fix scheduled job run on Master if `when` parameter is a list

- **PR** `#42414`_: (*vutny*) DOCS: unify hash sum with hash type format
  @ *2017-07-27T18:48:40Z*

  * f9cb536 Merge pull request `#42414`_ from vutny/unify-hash-params-format
  * d1f2a93 DOCS: unify hash sum with hash type format

- **PR** `#42523`_: (*rallytime*) Add a mention of the True/False returns with __virtual__()
  @ *2017-07-27T18:13:07Z*

  - **ISSUE** `#42375`_: (*dragonpaw*) salt.modules.*.__virtualname__ doens't work as documented.
    | refs: `#42523`_
  * 535c922 Merge pull request `#42523`_ from rallytime/`fix-42375`_
  * 685c2cc Add information about returning a tuple with an error message

  * fa46651 Add a mention of the True/False returns with __virtual__()

- **PR** `#42527`_: (*twangboy*) Document changes to Windows Update in Windows 10/Server 2016
  @ *2017-07-27T17:45:38Z*

  * 0df0e7e Merge pull request `#42527`_ from twangboy/win_wua
  * 0373791 Correct capatlization

  * af3bcc9 Document changes to Windows Update in 10/2016

- **PR** `#42551`_: (*binocvlar*) Remove '-s' (--script) argument to parted within align_check function
  @ *2017-07-27T17:35:31Z*

  * 69b0658 Merge pull request `#42551`_ from binocvlar/fix-lack-of-align-check-output
  * c4fabaa Remove '-s' (--script) argument to parted within align_check function

- **PR** `#42573`_: (*rallytime*) Back-port `#42433`_ to 2016.11
  @ *2017-07-27T13:51:21Z*

  - **ISSUE** `#42403`_: (*astronouth7303*) [2017.7] Pillar empty when state is applied from orchestrate
    | refs: `#42433`_
  - **PR** `#42433`_: (*terminalmage*) Only force saltenv/pillarenv to be a string when not None
    | refs: `#42573`_
  * 9e0b4e9 Merge pull request `#42573`_ from rallytime/`bp-42433`_
  * 0293429 Only force saltenv/pillarenv to be a string when not None

- **PR** `#42571`_: (*twangboy*) Avoid loading system PYTHON* environment vars
  @ *2017-07-26T22:48:55Z*

  * e931ed2 Merge pull request `#42571`_ from twangboy/win_add_pythonpath
  * d55a44d Avoid loading user site packages

  * 9af1eb2 Ignore any PYTHON* environment vars already on the system

  * 4e2fb03 Add pythonpath to batch files and service

- **PR** `#42387`_: (*DmitryKuzmenko*) Fix race condition in usage of weakvaluedict
  @ *2017-07-25T20:57:42Z*

  - **ISSUE** `#42371`_: (*tsaridas*) Minion unresponsive after trying to failover
    | refs: `#42387`_
  * de2f397 Merge pull request `#42387`_ from DSRCorporation/bugs/42371_KeyError_WeakValueDict
  * e721c7e Don't use `key in weakvaluedict` because it could lie.

- **PR** `#41968`_: (*root360-AndreasUlm*) Fix rabbitmqctl output sanitizer for version 3.6.10
  @ *2017-07-25T19:12:36Z*

  - **ISSUE** `#41955`_: (*root360-AndreasUlm*) rabbitmq 3.6.10 changed output => rabbitmq-module broken
    | refs: `#41968`_
  * 641a9d7 Merge pull request `#41968`_ from root360-AndreasUlm/fix-rabbitmqctl-output-handler
  * 76fd941 added tests for rabbitmq 3.6.10 output handler

  * 3602af1 Fix rabbitmqctl output handler for 3.6.10

- **PR** `#42479`_: (*gtmanfred*) validate ssh_interface for ec2
  @ *2017-07-25T18:37:18Z*

  - **ISSUE** `#42477`_: (*aikar*) Invalid ssh_interface value prevents salt-cloud provisioning without reason of why
    | refs: `#42479`_
  * 66fede3 Merge pull request `#42479`_ from gtmanfred/interface
  * c32c1b2 fix pylint

  * 99ec634 validate ssh_interface for ec2

- **PR** `#42516`_: (*rallytime*) Add info about top file to pillar walk-through example to include edit.vim
  @ *2017-07-25T17:01:12Z*

  - **ISSUE** `#42405`_: (*felrivero*) The documentation is incorrectly compiled (PILLAR section)
    | refs: `#42516`_
  * a925c70 Merge pull request `#42516`_ from rallytime/`fix-42405`_
  * e3a6717 Add info about top file to pillar walk-through example to include edit.vim

- **PR** `#42509`_: (*clem-compilatio*) Fix _assign_floating_ips in openstack.py
  @ *2017-07-24T17:14:13Z*

  - **ISSUE** `#42417`_: (*clem-compilatio*) salt-cloud - openstack - "no more floating IP addresses" error - but public_ip in node
    | refs: `#42509`_
  * 1bd5bbc Merge pull request `#42509`_ from clem-compilatio/`fix-42417`_
  * 72924b0 Fix _assign_floating_ips in openstack.py

- **PR** `#42464`_: (*garethgreenaway*) [2016.11] Small fix to modules/git.py
  @ *2017-07-21T21:28:57Z*

  * 4bf35a7 Merge pull request `#42464`_ from garethgreenaway/2016_11_remove_tmp_identity_file
  * ff24102 Uncomment the line that removes the temporary identity file.

- **PR** `#42443`_: (*garethgreenaway*) [2016.11] Fix to slack engine
  @ *2017-07-21T15:48:57Z*

  - **ISSUE** `#42357`_: (*Giandom*) Salt pillarenv problem with slack engine
    | refs: `#42443`_
  * e2120db Merge pull request `#42443`_ from garethgreenaway/42357_pass_args_kwargs_correctly
  * 635810b Updating the slack engine in 2016.11 to pass the args and kwrags correctly to LocalClient

- **PR** `#42200`_: (*shengis*) Fix `#42198`_
  @ *2017-07-21T14:47:29Z*

  - **ISSUE** `#42198`_: (*shengis*) state sqlite3.row_absent fail with "parameters are of unsupported type"
    | refs: `#42200`_
  * 8262cc9 Merge pull request `#42200`_ from shengis/sqlite3_fix_row_absent_2016.11
  * 407b8f4 Fix `#42198`_ If where_args is not set, not using it in the delete request.

- **PR** `#42424`_: (*goten4*) Fix error message when tornado or pycurl is not installed
  @ *2017-07-20T21:53:40Z*

  - **ISSUE** `#42413`_: (*goten4*) Invalid error message when proxy_host is set and tornado not installed
    | refs: `#42424`_
  * d9df97e Merge pull request `#42424`_ from goten4/2016.11
  * 1c0574d Fix error message when tornado or pycurl is not installed

- **PR** `#42350`_: (*twangboy*) Fixes problem with Version and OS Release related grains on certain versions of Python (2016.11)
  @ *2017-07-19T17:07:26Z*

  * 42bb1a6 Merge pull request `#42350`_ from twangboy/win_fix_ver_grains_2016.11
  * 8c04840 Detect Server OS with a desktop release name

- **PR** `#42356`_: (*meaksh*) Allow to check whether a function is available on the AliasesLoader wrapper
  @ *2017-07-19T16:56:41Z*

  * 0a72e56 Merge pull request `#42356`_ from meaksh/2016.11-AliasesLoader-wrapper-fix
  * 915d942 Allow to check whether a function is available on the AliasesLoader wrapper

- **PR** `#42368`_: (*twangboy*) Remove build and dist directories before install (2016.11)
  @ *2017-07-19T16:47:28Z*

  * 10eb7b7 Merge pull request `#42368`_ from twangboy/win_fix_build_2016.11
  * a7c910c Remove build and dist directories before install

- **PR** `#42370`_: (*rallytime*) [2016.11] Merge forward from 2016.3 to 2016.11
  @ *2017-07-18T22:39:41Z*

  - **PR** `#42359`_: (*Ch3LL*) [2016.3] Update version numbers in doc config for 2017.7.0 release
  * 016189f Merge pull request `#42370`_ from rallytime/merge-2016.11
  * 0aa5dde Merge branch '2016.3' into '2016.11'

  * e9b0f20 Merge pull request `#42359`_ from Ch3LL/doc-update-2016.3

    * dc85b5e [2016.3] Update version numbers in doc config for 2017.7.0 release

- **PR** `#42360`_: (*Ch3LL*) [2016.11] Update version numbers in doc config for 2017.7.0 release
  @ *2017-07-18T19:23:30Z*

  * f06a6f1 Merge pull request `#42360`_ from Ch3LL/doc-update-2016.11
  * b90b7a7 [2016.11] Update version numbers in doc config for 2017.7.0 release

- **PR** `#42319`_: (*rallytime*) Add more documentation for config options that are missing from master/minion docs
  @ *2017-07-18T18:02:32Z*

  - **ISSUE** `#32400`_: (*rallytime*) Document Default Config Values
    | refs: `#42319`_
  * e0595b0 Merge pull request `#42319`_ from rallytime/config-docs
  * b40f980 Add more documentation for config options that are missing from master/minion docs

- **PR** `#42352`_: (*CorvinM*) Multiple documentation fixes
  @ *2017-07-18T15:10:37Z*

  - **ISSUE** `#42333`_: (*b3hni4*) Getting "invalid type of dict, a list is required" when trying to configure engines in master config file
    | refs: `#42352`_
  * 7894040 Merge pull request `#42352`_ from CorvinM/issue42333
  * 526b6ee Multiple documentation fixes

- **PR** `#42353`_: (*terminalmage*) is_windows is a function, not a propery/attribute
  @ *2017-07-18T14:38:51Z*

  * b256001 Merge pull request `#42353`_ from terminalmage/fix-git-test
  * 14cf6ce is_windows is a function, not a propery/attribute

- **PR** `#42264`_: (*rallytime*) Update minion restart section in FAQ doc for windows
  @ *2017-07-17T17:40:40Z*

  - **ISSUE** `#41116`_: (*hrumph*) FAQ has wrong instructions for upgrading Windows minion.
    | refs: `#42264`_
  * 866a1fe Merge pull request `#42264`_ from rallytime/`fix-41116`_
  * bd63888 Add mono-spacing to salt-minion reference for consistency

  * 30d62f4 Update minion restart section in FAQ doc for windows

- **PR** `#42275`_: (*terminalmage*) pkg.installed: pack name/version into pkgs argument
  @ *2017-07-17T17:38:39Z*

  - **ISSUE** `#42194`_: (*jryberg*) pkg version: latest are now broken, appending <package>-latest to filename
    | refs: `#42275`_
  * 9a70708 Merge pull request `#42275`_ from terminalmage/issue42194
  * 6638749 pkg.installed: pack name/version into pkgs argument

- **PR** `#42269`_: (*rallytime*) Add some clarity to "multiple quotes" section of yaml docs
  @ *2017-07-17T17:38:18Z*

  - **ISSUE** `#41721`_: (*sazaro*) state.sysrc broken when setting the value to YES or NO
    | refs: `#42269`_
  * e588f23 Merge pull request `#42269`_ from rallytime/`fix-41721`_
  * f2250d4 Add a note about using different styles of quotes.

  * 38d9b3d Add some clarity to "multiple quotes" section of yaml docs

- **PR** `#42282`_: (*rallytime*) Handle libcloud objects that throw RepresenterErrors with --out=yaml
  @ *2017-07-17T17:36:35Z*

  - **ISSUE** `#42152`_: (*dubb-b*) salt-cloud errors on Rackspace driver using -out=yaml 
    | refs: `#42282`_
  * 5aaa214 Merge pull request `#42282`_ from rallytime/`fix-42152`_
  * f032223 Handle libcloud objects that throw RepresenterErrors with --out=yaml

- **PR** `#42308`_: (*lubyou*) Force file removal on Windows. Fixes `#42295`_
  @ *2017-07-17T17:12:13Z*

  - **ISSUE** `#42295`_: (*lubyou*) file.absent fails on windows if the file to be removed has the "readonly" attribute set
    | refs: `#42308`_
  * fb5697a Merge pull request `#42308`_ from lubyou/42295-fix-file-absent-windows
  * 026ccf4 Force file removal on Windows. Fixes `#42295`_

- **PR** `#42314`_: (*rallytime*) Add clarification to salt ssh docs about key auto-generation.
  @ *2017-07-17T14:07:49Z*

  - **ISSUE** `#42267`_: (*gzcwnk*) salt-ssh not creating ssh keys automatically as per documentation
    | refs: `#42314`_
  * da2a8a5 Merge pull request `#42314`_ from rallytime/`fix-42267`_
  * c406046 Add clarification to salt ssh docs about key auto-generation.

- **PR** `#41945`_: (*garethgreenaway*) Fixes to modules/git.py
  @ *2017-07-14T17:46:10Z*

  - **ISSUE** `#41936`_: (*michaelkarrer81*) git.latest identity does not set the correct user for the private key file on the minion
    | refs: `#41945`_
  - **ISSUE** `#1`_: (*thatch45*) Enable regex on the salt cli
  * acadd54 Merge pull request `#41945`_ from garethgreenaway/41936_allow_identity_files_with_user
  * 44841e5 Moving the call to cp.get_file inside the with block to ensure the umask is preserved when we grab the file.

  * f9ba60e Merge pull request `#1`_ from terminalmage/pr-41945

    * 1b60261 Restrict set_umask to mkstemp call only

  * 68549f3 Fixing umask to we can set files as executable.

  * 4949bf3 Updating to swap on the new salt.utils.files.set_umask context_manager

  * 8faa9f6 Updating PR with requested changes.

  * 494765e Updating the git module to allow an identity file to be used when passing the user parameter

- **PR** `#42289`_: (*CorvinM*) Multiple empty_password fixes for state.user
  @ *2017-07-14T16:14:02Z*

  - **ISSUE** `#42240`_: (*casselt*) empty_password in user.present always changes password, even with test=True
    | refs: `#42289`_
  - **PR** `#41543`_: (*cri-epita*) Fix user creation with empty password
    | refs: `#42289`_ `#42289`_
  * f90e04a Merge pull request `#42289`_ from CorvinM/`bp-41543`_
  * 357dc22 Fix user creation with empty password

- **PR** `#42123`_: (*vutny*) DOCS: describe importing custom util classes
  @ *2017-07-12T15:53:24Z*

  * a91a3f8 Merge pull request `#42123`_ from vutny/fix-master-utils-import
  * 6bb8b8f Add missing doc for ``utils_dirs`` Minion config option

  * f1bc58f Utils: add example of module import

- **PR** `#42261`_: (*rallytime*) Some minor doc fixes for dnsutil module so they'll render correctly
  @ *2017-07-11T23:14:53Z*

  * e2aa511 Merge pull request `#42261`_ from rallytime/minor-doc-fix
  * 8c76bbb Some minor doc fixes for dnsutil module so they'll render correctly

- **PR** `#42262`_: (*rallytime*) Back-port `#42224`_ to 2016.11
  @ *2017-07-11T23:14:25Z*

  - **PR** `#42224`_: (*tdutrion*) Remove duplicate instruction in Openstack Rackspace config example
    | refs: `#42262`_
  * 3e9dfbc Merge pull request `#42262`_ from rallytime/`bp-42224`_
  * c31ded3 Remove duplicate instruction in Openstack Rackspace config example

- **PR** `#42181`_: (*garethgreenaway*) fixes to state.py for names parameter
  @ *2017-07-11T21:21:32Z*

  - **ISSUE** `#42137`_: (*kiemlicz*) cmd.run with multiple commands - random order of execution
    | refs: `#42181`_
  * 7780579 Merge pull request `#42181`_ from garethgreenaway/42137_backport_fix_from_2017_7
  * a34970b Back porting the fix for 2017.7 that ensures the order of the names parameter.

- **PR** `#42253`_: (*gtmanfred*) Only use unassociated ips when unable to allocate
  @ *2017-07-11T20:53:51Z*

  - **PR** `#38965`_: (*toanju*) salt-cloud will use list_floating_ips for OpenStack
    | refs: `#42253`_
  - **PR** `#34280`_: (*kevinanderson1*) salt-cloud will use list_floating_ips for Openstack
    | refs: `#38965`_
  * 7253786 Merge pull request `#42253`_ from gtmanfred/2016.11
  * 53e2576 Only use unassociated ips when unable to allocate

- **PR** `#42252`_: (*UtahDave*) simple docstring updates
  @ *2017-07-11T20:48:33Z*

  * b2a4698 Merge pull request `#42252`_ from UtahDave/2016.11local
  * e6a9563 simple doc updates

- **PR** `#42235`_: (*astronouth7303*) Abolish references to `dig` in examples.
  @ *2017-07-10T20:06:11Z*

  - **ISSUE** `#42232`_: (*astronouth7303*) Half of dnsutil refers to dig
    | refs: `#42235`_
  * 781fe13 Merge pull request `#42235`_ from astronouth7303/patch-1-2016.3
  * 4cb51bd Make note of dig partial requirement.

  * 08e7d83 Abolish references to `dig` in examples.

- **PR** `#42215`_: (*twangboy*) Add missing config to example
  @ *2017-07-07T20:18:44Z*

  * 83cbd76 Merge pull request `#42215`_ from twangboy/win_iis_docs
  * c07e220 Add missing config to example

- **PR** `#42211`_: (*terminalmage*) Only pass a saltenv in orchestration if one was explicitly passed (2016.11)
  @ *2017-07-07T20:16:35Z*

  * 274946a Merge pull request `#42211`_ from terminalmage/issue40928
  * 22a18fa Only pass a saltenv in orchestration if one was explicitly passed (2016.11)

- **PR** `#42173`_: (*rallytime*) Back-port `#37424`_ to 2016.11
  @ *2017-07-07T16:39:59Z*

  - **PR** `#37424`_: (*kojiromike*) Avoid Early Convert ret['comment'] to String
    | refs: `#42173`_
  * 89261cf Merge pull request `#42173`_ from rallytime/`bp-37424`_
  * 01addb6 Avoid Early Convert ret['comment'] to String

- **PR** `#42175`_: (*rallytime*) Back-port `#39366`_ to 2016.11
  @ *2017-07-06T19:51:47Z*

  - **ISSUE** `#39365`_: (*dglloyd*) service.running fails if sysv script has no status command and enable: True
    | refs: `#39366`_
  - **PR** `#39366`_: (*dglloyd*) Pass sig to service.status in after_toggle
    | refs: `#42175`_
  * 3b17fb7 Merge pull request `#42175`_ from rallytime/`bp-39366`_
  * 53f7b98 Pass sig to service.status in after_toggle

- **PR** `#42172`_: (*rallytime*) [2016.11] Merge forward from 2016.3 to 2016.11
  @ *2017-07-06T18:16:29Z*

  - **PR** `#42155`_: (*phsteve*) Fix docs for puppet.plugin_sync
  * ea16f47 Merge pull request `#42172`_ from rallytime/merge-2016.11
  * b1fa332 Merge branch '2016.3' into '2016.11'

    * 8fa1fa5 Merge pull request `#42155`_ from phsteve/doc-fix-puppet

      * fb2cb78 Fix docs for puppet.plugin_sync so code-block renders properly and sync is spelled consistently

- **PR** `#42176`_: (*rallytime*) Back-port `#42109`_ to 2016.11
  @ *2017-07-06T18:15:35Z*

  - **PR** `#42109`_: (*arthurlogilab*) [doc] Update aws.rst - add Debian default username
    | refs: `#42176`_
  * 6307b98 Merge pull request `#42176`_ from rallytime/`bp-42109`_
  * 686926d Update aws.rst - add Debian default username

- **PR** `#42095`_: (*terminalmage*) Add debug logging to dockerng.login
  @ *2017-07-06T17:13:05Z*

  * 28c4e4c Merge pull request `#42095`_ from terminalmage/docker-login-debugging
  * bd27870 Add debug logging to dockerng.login

- **PR** `#42119`_: (*terminalmage*) Fix regression in CLI pillar override for salt-call
  @ *2017-07-06T17:02:52Z*

  - **ISSUE** `#42116`_: (*terminalmage*) CLI pillar override regression in 2017.7.0rc1
    | refs: `#42119`_
  * 2b754bc Merge pull request `#42119`_ from terminalmage/issue42116
  * 9a26894 Add integration test for 42116

  * 1bb42bb Fix regression when CLI pillar override is used with salt-call

- **PR** `#42121`_: (*terminalmage*) Fix pillar.get when saltenv is passed
  @ *2017-07-06T16:52:34Z*

  - **ISSUE** `#42114`_: (*clallen*) saltenv bug in pillar.get execution module function
    | refs: `#42121`_
  * 8c0a83c Merge pull request `#42121`_ from terminalmage/issue42114
  * d142912 Fix pillar.get when saltenv is passed

- **PR** `#42094`_: (*terminalmage*) Prevent command from showing in exception when output_loglevel=quiet
  @ *2017-07-06T16:18:09Z*

  * 687992c Merge pull request `#42094`_ from terminalmage/quiet-exception
  * 47d61f4 Prevent command from showing in exception when output_loglevel=quiet

- **PR** `#42163`_: (*vutny*) Fix `#42115`_: parse libcloud "rc" version correctly
  @ *2017-07-06T16:15:07Z*

  - **ISSUE** `#42115`_: (*nomeelnoj*) Installing EPEL repo breaks salt-cloud
    | refs: `#42163`_
  * dad2551 Merge pull request `#42163`_ from vutny/`fix-42115`_
  * b27b1e3 Fix `#42115`_: parse libcloud "rc" version correctly

- **PR** `#42164`_: (*Ch3LL*) Fix kerberos create_keytab doc
  @ *2017-07-06T15:55:33Z*

  * 2a8ae2b Merge pull request `#42164`_ from Ch3LL/fix_kerb_doc
  * 7c0fb24 Fix kerberos create_keytab doc

- **PR** `#42141`_: (*rallytime*) Back-port `#42098`_ to 2016.11
  @ *2017-07-06T15:11:49Z*

  - **PR** `#42098`_: (*twangboy*) Change repo_ng to repo-ng
    | refs: `#42141`_
  * 678d4d4 Merge pull request `#42141`_ from rallytime/`bp-42098`_
  * bd80243 Change repo_ng to repo-ng

- **PR** `#42140`_: (*rallytime*) Back-port `#42097`_ to 2016.11
  @ *2017-07-06T15:11:29Z*

  - **PR** `#42097`_: (*gtmanfred*) require large timediff for ipv6 warning
    | refs: `#42140`_
  * c8afd7a Merge pull request `#42140`_ from rallytime/`bp-42097`_
  * 9c4e132 Import datetime

  * 1435bf1 require large timediff for ipv6 warning

- **PR** `#42142`_: (*Ch3LL*) Update builds available for rc1
  @ *2017-07-05T21:11:56Z*

  * c239664 Merge pull request `#42142`_ from Ch3LL/change_builds
  * e1694af Update builds available for rc1

- **PR** `#42078`_: (*damon-atkins*) pkg.install and pkg.remove fix version number input.
  @ *2017-07-05T06:04:57Z*

  * 4780d78 Merge pull request `#42078`_ from damon-atkins/fix_convert_flt_str_version_on_cmd_line
  * 09d37dd Fix comment typo

  * 7167549 Handle version=None  when converted to a string it becomes 'None' parm should default to empty string rather than None, it would fix better with existing code.

  * 4fb2bb1 Fix typo

  * cf55c33 pkg.install and pkg.remove on the command line take number version numbers, store them within a float. However version is a string, to support versions numbers like 1.3.4

- **PR** `#42105`_: (*Ch3LL*) Update releasecanddiate doc with new 2017.7.0rc1 Release
  @ *2017-07-04T03:14:42Z*

  * 46d575a Merge pull request `#42105`_ from Ch3LL/update_rc
  * d4e7b91 Update releasecanddiate doc with new 2017.7.0rc1 Release

- **PR** `#42099`_: (*rallytime*) Remove references in docs to pip install salt-cloud
  @ *2017-07-03T22:13:44Z*

  - **ISSUE** `#41885`_: (*astronouth7303*) Recommended pip installation outdated?
    | refs: `#42099`_
  * d38548b Merge pull request `#42099`_ from rallytime/`fix-41885`_
  * c2822e0 Remove references in docs to pip install salt-cloud

- **PR** `#42086`_: (*abulford*) Make result=true if Docker volume already exists
  @ *2017-07-03T15:48:33Z*

  - **ISSUE** `#42076`_: (*abulford*) dockerng.volume_present test looks as though it would cause a change
    | refs: `#42086`_ `#42086`_
  * 81d606a Merge pull request `#42086`_ from redmatter/fix-dockerng-volume-present-result
  * 8d54968 Make result=true if Docker volume already exists

- **PR** `#42021`_: (*gtmanfred*) Set concurrent to True when running states with sudo
  @ *2017-06-30T21:02:15Z*

  - **ISSUE** `#25842`_: (*shikhartanwar*) Running salt-minion as non-root user to execute sudo commands always returns an error
    | refs: `#42021`_
  * 7160697 Merge pull request `#42021`_ from gtmanfred/2016.11
  * 26beb18 Set concurrent to True when running states with sudo

- **PR** `#42029`_: (*terminalmage*) Mock socket.getaddrinfo in unit.utils.network_test.NetworkTestCase.test_host_to_ips
  @ *2017-06-30T20:58:56Z*

  * b784fbb Merge pull request `#42029`_ from terminalmage/host_to_ips
  * 26f848e Mock socket.getaddrinfo in unit.utils.network_test.NetworkTestCase.test_host_to_ips

- **PR** `#42055`_: (*dmurphy18*) Upgrade support for gnupg v2.1 and higher
  @ *2017-06-30T20:54:02Z*

  * e067020 Merge pull request `#42055`_ from dmurphy18/handle_gnupgv21
  * e20cea6 Upgrade support for gnupg v2.1 and higher

- **PR** `#42048`_: (*Ch3LL*) Add initial 2016.11.7 Release Notes
  @ *2017-06-30T16:00:05Z*

  * 74ba2ab Merge pull request `#42048`_ from Ch3LL/add_11.7
  * 1de5e00 Add initial 2016.11.7 Release Notes

- **PR** `#42024`_: (*leeclemens*) doc: Specify versionadded for SELinux policy install/uninstall
  @ *2017-06-29T23:29:50Z*

  * ca4e619 Merge pull request `#42024`_ from leeclemens/doc/selinux
  * b63a3c0 doc: Specify versionadded for SELinux policy install/uninstall

- **PR** `#42030`_: (*whiteinge*) Re-add msgpack to mocked imports
  @ *2017-06-29T20:47:59Z*

  - **PR** `#42028`_: (*whiteinge*) Revert "Allow docs to be built under Python 3"
    | refs: `#42030`_
  - **PR** `#41961`_: (*cachedout*) Allow docs to be built under Python 3
    | refs: `#42028`_
  * 50856d0 Merge pull request `#42030`_ from whiteinge/revert-py3-doc-chagnes-pt-2
  * 18dfa98 Re-add msgpack to mocked imports

- **PR** `#42028`_: (*whiteinge*) Revert "Allow docs to be built under Python 3"
  | refs: `#42030`_
  @ *2017-06-29T19:47:46Z*

  - **PR** `#41961`_: (*cachedout*) Allow docs to be built under Python 3
    | refs: `#42028`_
  * 53031d2 Merge pull request `#42028`_ from saltstack/revert-41961-py3_doc
  * 5592e6e Revert "Allow docs to be built under Python 3"

- **PR** `#42017`_: (*lorengordon*) Fixes typo "nozerconf" -> "nozeroconf"
  @ *2017-06-29T17:30:48Z*

  - **ISSUE** `#42013`_: (*dusto*) Misspelled nozeroconf in salt/modules/rh_ip.py
    | refs: `#42017`_
  * 1416bf7 Merge pull request `#42017`_ from lorengordon/issue-42013
  * b6cf5f2 Fixes typo nozerconf -> nozeroconf

- **PR** `#41906`_: (*terminalmage*) Better support for numeric saltenvs
  @ *2017-06-29T17:19:33Z*

  * 0ebb50b Merge pull request `#41906`_ from terminalmage/numeric-saltenv
  * 2d798de Better support for numeric saltenvs

- **PR** `#41995`_: (*terminalmage*) Temporarily set the umask before writing an auth token
  @ *2017-06-29T01:09:48Z*

  * 6a3c03c Merge pull request `#41995`_ from terminalmage/token-umask
  * 4f54b00 Temporarily set the umask before writing an auth token

- **PR** `#41999`_: (*terminalmage*) Update IP address for unit.utils.network_test.NetworkTestCase.test_host_to_ips
  @ *2017-06-29T01:01:31Z*

  * e3801b0 Merge pull request `#41999`_ from terminalmage/fix-network-test
  * fb6a933 Update IP address for unit.utils.network_test.NetworkTestCase.test_host_to_ips

- **PR** `#41991`_: (*Da-Juan*) Accept a list for state_aggregate global setting
  @ *2017-06-29T00:58:59Z*

  - **ISSUE** `#18659`_: (*whiteinge*) mod_aggregate not working for list-form configuration
    | refs: `#41991`_
  * a7f3892 Merge pull request `#41991`_ from Da-Juan/fix-state_aggregate-list
  * c9075b8 Accept a list for state_aggregate setting

- **PR** `#41993`_: (*UtahDave*) change out salt support link to SaltConf link
  @ *2017-06-29T00:55:20Z*

  * 7424f87 Merge pull request `#41993`_ from UtahDave/2016.11local
  * bff050a change out salt support link to SaltConf link

- **PR** `#41987`_: (*rallytime*) [2016.11] Merge forward from 2016.3 to 2016.11
  @ *2017-06-28T20:19:11Z*

  - **PR** `#41981`_: (*Ch3LL*) [2016.3] Bump latest release version to 2016.11.6
  * 3b9ccf0 Merge pull request `#41987`_ from rallytime/merge-2016.11
  * 48867c4 Merge branch '2016.3' into '2016.11'

    * c589eae Merge pull request `#41981`_ from Ch3LL/11.6_3

    * 2516ae1 [2016.3] Bump latest release version to 2016.11.6

- **PR** `#41985`_: (*rallytime*) Back-port `#41780`_ to 2016.11
  @ *2017-06-28T20:18:57Z*

  - **PR** `#41780`_: (*ferringb*) Fix salt.util.render_jinja_tmpl usage for when not used in an environmnet
    | refs: `#41985`_
  * 768339d Merge pull request `#41985`_ from rallytime/`bp-41780`_
  * 8f8d3a4 Fix salt.util.render_jinja_tmpl usage for when not used in an environment.

- **PR** `#41986`_: (*rallytime*) Back-port `#41820`_ to 2016.11
  @ *2017-06-28T20:18:43Z*

  - **ISSUE** `#34963`_: (*craigafinch*) Incorrect behavior or documentation for comments in salt.states.pkgrepo.managed
    | refs: `#41820`_
  - **PR** `#41820`_: (*nhavens*) Fix yum repo file comments to work as documented in pkgrepo.managed
    | refs: `#41986`_
  * bd9090c Merge pull request `#41986`_ from rallytime/`bp-41820`_
  * 72320e3 Fix yum repo file comments to work as documented in pkgrepo.managed

- **PR** `#41973`_: (*vutny*) Fix Master/Minion scheduled jobs based on Cron expressions
  | refs: `#42077`_
  @ *2017-06-28T16:39:02Z*

  * a31da52 Merge pull request `#41973`_ from vutny/fix-croniter-scheduled-jobs
  * 148788e Fix Master/Minion scheduled jobs based on Cron expressions

- **PR** `#41980`_: (*Ch3LL*) [2016.11] Bump latest release version to 2016.11.6
  @ *2017-06-28T15:35:11Z*

  * 689ff93 Merge pull request `#41980`_ from Ch3LL/11.6_11
  * fe4f571 [2016.11] Bump latest release version to 2016.11.6

- **PR** `#41961`_: (*cachedout*) Allow docs to be built under Python 3
  | refs: `#42028`_
  @ *2017-06-27T21:11:54Z*

  * 82b1eb2 Merge pull request `#41961`_ from cachedout/py3_doc
  * 7aacddf Allow docs to be built under Python 3

- **PR** `#41948`_: (*davidjb*) Fix Composer state's `name` docs; formatting
  @ *2017-06-27T17:51:29Z*

  - **PR** `#41933`_: (*davidjb*) Fix Composer state's `name` docs and improve formatting
    | refs: `#41948`_
  * f0eb51d Merge pull request `#41948`_ from davidjb/patch-9
  * 0e4b3d9 Fix Composer state's `name` docs; formatting

- **PR** `#41914`_: (*vutny*) archive.extracted: fix hash sum verification for local archives
  @ *2017-06-26T17:59:27Z*

  * e28e10d Merge pull request `#41914`_ from vutny/fix-archive-extracted-local-file-hash
  * 54910fe archive.extracted: fix hash sum verification for local archives

- **PR** `#41912`_: (*Ch3LL*) Allow pacman module to run on Manjaro
  @ *2017-06-26T15:35:20Z*

  * 76ad6ff Merge pull request `#41912`_ from Ch3LL/fix_manjaro
  * e4dd72a Update os_name_map in core grains for new manjaro systems

  * aa7c839 Allow pacman module to run on Manjaro

- **PR** `#41516`_: (*kstreee*) Implements MessageClientPool to avoid blocking waiting for zeromq and tcp communications.
  @ *2017-06-26T14:41:38Z*

  - **ISSUE** `#38093`_: (*DmitryKuzmenko*) Make threads avoid blocking waiting while communicating using TCP transport.
    | refs: `#41516`_ `#41516`_
  - **PR** `#37878`_: (*kstreee*) Makes threads avoid blocking waiting while communicating using Zeromq.
    | refs: `#41516`_ `#41516`_
  * ff67d47 Merge pull request `#41516`_ from kstreee/fix-blocking-waiting-tcp-connection
  * df96969 Removes redundant closing statements.

  * 94b9ea5 Implements MessageClientPool to avoid blocking waiting for zeromq and tcp communications.

- **PR** `#41888`_: (*Ch3LL*) Add additional commits to 2016.11.6 release notes
  @ *2017-06-22T16:19:00Z*

  * c90cb67 Merge pull request `#41888`_ from Ch3LL/change_release
  * 4e1239d Add additional commits to 2016.11.6 release notes

- **PR** `#41882`_: (*Ch3LL*) Add pycryptodome to crypt_test
  @ *2017-06-21T19:51:10Z*

  * 4a32644 Merge pull request `#41882`_ from Ch3LL/fix_crypt_test
  * 6f70dbd Add pycryptodome to crypt_test

- **PR** `#41877`_: (*Ch3LL*) Fix netstat and routes test
  @ *2017-06-21T16:16:58Z*

  * 13df29e Merge pull request `#41877`_ from Ch3LL/fix_netstat_test
  * d2076a6 Patch salt.utils.which for test_route test

  * 51f7e10 Patch salt.utils.which for test_netstat test

- **PR** `#41566`_: (*morganwillcock*) win_certutil: workaround for reading serial numbers with non-English languages
  @ *2017-06-21T15:40:29Z*

  - **ISSUE** `#41367`_: (*lubyou*) certutil.add_store does not work on non english windows versions or on Windows 10 (localised or English)
    | refs: `#41566`_
  * 66f8c83 Merge pull request `#41566`_ from morganwillcock/certutil
  * c337d52 Fix test data for test_get_serial, and a typo

  * 7f69613 test and lint fixes

  * 8ee4843 Suppress output of crypt context and be more specifc with whitespace vs. serial

  * 61f817d Match serials based on output position (fix for non-English languages)

- **PR** `#41679`_: (*terminalmage*) Prevent unnecessary duplicate pillar compilation
  @ *2017-06-21T15:32:42Z*

  * 4d0f5c4 Merge pull request `#41679`_ from terminalmage/get-top-file-envs
  * a916e8d Improve normalization of saltenv/pillarenv usage for states

  * 02f293a Update state unit tests to reflect recent changes

  * b7e5c11 Don't compile pillar data when getting top file envs

  * 8d6fdb7 Don't compile pillar twice for salt-call

  * d2abfbf Add initial_pillar argument to salt.state

  * 70186de salt.pillar: rename the "pillar" argument to "pillar_override"

- **PR** `#41853`_: (*vutny*) Fix master side scheduled jobs to return events
  @ *2017-06-20T22:06:29Z*

  - **ISSUE** `#39668`_: (*mirceaulinic*) Master scheduled job not recorded on the event bus
    | refs: `#41658`_
  - **ISSUE** `#12653`_: (*pengyao*) salt schedule doesn't return jobs result info to master
    | refs: `#41853`_
  - **PR** `#41695`_: (*xiaoanyunfei*) fix max RecursionError, Ellipsis
    | refs: `#41853`_
  - **PR** `#41658`_: (*garethgreenaway*) Fixes to the salt scheduler
    | refs: `#41853`_
  * 29b0acc Merge pull request `#41853`_ from vutny/fix-master-schedule-event
  * e206c38 Fix master side scheduled jobs to return events


.. _`#1`: https://github.com/saltstack/salt/issues/1
.. _`#1036125`: https://github.com/saltstack/salt/issues/1036125
.. _`#12653`: https://github.com/saltstack/salt/issues/12653
.. _`#15171`: https://github.com/saltstack/salt/issues/15171
.. _`#18659`: https://github.com/saltstack/salt/issues/18659
.. _`#23516`: https://github.com/saltstack/salt/issues/23516
.. _`#25842`: https://github.com/saltstack/salt/issues/25842
.. _`#32400`: https://github.com/saltstack/salt/issues/32400
.. _`#33806`: https://github.com/saltstack/salt/pull/33806
.. _`#34280`: https://github.com/saltstack/salt/pull/34280
.. _`#34963`: https://github.com/saltstack/salt/issues/34963
.. _`#37424`: https://github.com/saltstack/salt/pull/37424
.. _`#37878`: https://github.com/saltstack/salt/pull/37878
.. _`#38093`: https://github.com/saltstack/salt/issues/38093
.. _`#38839`: https://github.com/saltstack/salt/issues/38839
.. _`#38965`: https://github.com/saltstack/salt/pull/38965
.. _`#39365`: https://github.com/saltstack/salt/issues/39365
.. _`#39366`: https://github.com/saltstack/salt/pull/39366
.. _`#39668`: https://github.com/saltstack/salt/issues/39668
.. _`#40490`: https://github.com/saltstack/salt/issues/40490
.. _`#41116`: https://github.com/saltstack/salt/issues/41116
.. _`#41367`: https://github.com/saltstack/salt/issues/41367
.. _`#41433`: https://github.com/saltstack/salt/issues/41433
.. _`#41516`: https://github.com/saltstack/salt/pull/41516
.. _`#41543`: https://github.com/saltstack/salt/pull/41543
.. _`#41566`: https://github.com/saltstack/salt/pull/41566
.. _`#41658`: https://github.com/saltstack/salt/pull/41658
.. _`#41679`: https://github.com/saltstack/salt/pull/41679
.. _`#41695`: https://github.com/saltstack/salt/pull/41695
.. _`#41721`: https://github.com/saltstack/salt/issues/41721
.. _`#41770`: https://github.com/saltstack/salt/issues/41770
.. _`#41780`: https://github.com/saltstack/salt/pull/41780
.. _`#41820`: https://github.com/saltstack/salt/pull/41820
.. _`#41853`: https://github.com/saltstack/salt/pull/41853
.. _`#41877`: https://github.com/saltstack/salt/pull/41877
.. _`#41882`: https://github.com/saltstack/salt/pull/41882
.. _`#41885`: https://github.com/saltstack/salt/issues/41885
.. _`#41888`: https://github.com/saltstack/salt/pull/41888
.. _`#41906`: https://github.com/saltstack/salt/pull/41906
.. _`#41912`: https://github.com/saltstack/salt/pull/41912
.. _`#41914`: https://github.com/saltstack/salt/pull/41914
.. _`#41933`: https://github.com/saltstack/salt/pull/41933
.. _`#41936`: https://github.com/saltstack/salt/issues/41936
.. _`#41945`: https://github.com/saltstack/salt/pull/41945
.. _`#41948`: https://github.com/saltstack/salt/pull/41948
.. _`#41955`: https://github.com/saltstack/salt/issues/41955
.. _`#41961`: https://github.com/saltstack/salt/pull/41961
.. _`#41968`: https://github.com/saltstack/salt/pull/41968
.. _`#41973`: https://github.com/saltstack/salt/pull/41973
.. _`#41976`: https://github.com/saltstack/salt/issues/41976
.. _`#41977`: https://github.com/saltstack/salt/pull/41977
.. _`#41980`: https://github.com/saltstack/salt/pull/41980
.. _`#41981`: https://github.com/saltstack/salt/pull/41981
.. _`#41982`: https://github.com/saltstack/salt/issues/41982
.. _`#41985`: https://github.com/saltstack/salt/pull/41985
.. _`#41986`: https://github.com/saltstack/salt/pull/41986
.. _`#41987`: https://github.com/saltstack/salt/pull/41987
.. _`#41988`: https://github.com/saltstack/salt/pull/41988
.. _`#41991`: https://github.com/saltstack/salt/pull/41991
.. _`#41993`: https://github.com/saltstack/salt/pull/41993
.. _`#41995`: https://github.com/saltstack/salt/pull/41995
.. _`#41999`: https://github.com/saltstack/salt/pull/41999
.. _`#42013`: https://github.com/saltstack/salt/issues/42013
.. _`#42017`: https://github.com/saltstack/salt/pull/42017
.. _`#42021`: https://github.com/saltstack/salt/pull/42021
.. _`#42024`: https://github.com/saltstack/salt/pull/42024
.. _`#42028`: https://github.com/saltstack/salt/pull/42028
.. _`#42029`: https://github.com/saltstack/salt/pull/42029
.. _`#42030`: https://github.com/saltstack/salt/pull/42030
.. _`#42041`: https://github.com/saltstack/salt/issues/42041
.. _`#42045`: https://github.com/saltstack/salt/pull/42045
.. _`#42048`: https://github.com/saltstack/salt/pull/42048
.. _`#42055`: https://github.com/saltstack/salt/pull/42055
.. _`#42076`: https://github.com/saltstack/salt/issues/42076
.. _`#42077`: https://github.com/saltstack/salt/pull/42077
.. _`#42078`: https://github.com/saltstack/salt/pull/42078
.. _`#42086`: https://github.com/saltstack/salt/pull/42086
.. _`#42094`: https://github.com/saltstack/salt/pull/42094
.. _`#42095`: https://github.com/saltstack/salt/pull/42095
.. _`#42097`: https://github.com/saltstack/salt/pull/42097
.. _`#42098`: https://github.com/saltstack/salt/pull/42098
.. _`#42099`: https://github.com/saltstack/salt/pull/42099
.. _`#42105`: https://github.com/saltstack/salt/pull/42105
.. _`#42109`: https://github.com/saltstack/salt/pull/42109
.. _`#42114`: https://github.com/saltstack/salt/issues/42114
.. _`#42115`: https://github.com/saltstack/salt/issues/42115
.. _`#42116`: https://github.com/saltstack/salt/issues/42116
.. _`#42119`: https://github.com/saltstack/salt/pull/42119
.. _`#42121`: https://github.com/saltstack/salt/pull/42121
.. _`#42123`: https://github.com/saltstack/salt/pull/42123
.. _`#42137`: https://github.com/saltstack/salt/issues/42137
.. _`#42140`: https://github.com/saltstack/salt/pull/42140
.. _`#42141`: https://github.com/saltstack/salt/pull/42141
.. _`#42142`: https://github.com/saltstack/salt/pull/42142
.. _`#42152`: https://github.com/saltstack/salt/issues/42152
.. _`#42155`: https://github.com/saltstack/salt/pull/42155
.. _`#42163`: https://github.com/saltstack/salt/pull/42163
.. _`#42164`: https://github.com/saltstack/salt/pull/42164
.. _`#42172`: https://github.com/saltstack/salt/pull/42172
.. _`#42173`: https://github.com/saltstack/salt/pull/42173
.. _`#42175`: https://github.com/saltstack/salt/pull/42175
.. _`#42176`: https://github.com/saltstack/salt/pull/42176
.. _`#42181`: https://github.com/saltstack/salt/pull/42181
.. _`#42194`: https://github.com/saltstack/salt/issues/42194
.. _`#42198`: https://github.com/saltstack/salt/issues/42198
.. _`#42200`: https://github.com/saltstack/salt/pull/42200
.. _`#42211`: https://github.com/saltstack/salt/pull/42211
.. _`#42215`: https://github.com/saltstack/salt/pull/42215
.. _`#42224`: https://github.com/saltstack/salt/pull/42224
.. _`#42232`: https://github.com/saltstack/salt/issues/42232
.. _`#42235`: https://github.com/saltstack/salt/pull/42235
.. _`#42240`: https://github.com/saltstack/salt/issues/42240
.. _`#42252`: https://github.com/saltstack/salt/pull/42252
.. _`#42253`: https://github.com/saltstack/salt/pull/42253
.. _`#42261`: https://github.com/saltstack/salt/pull/42261
.. _`#42262`: https://github.com/saltstack/salt/pull/42262
.. _`#42264`: https://github.com/saltstack/salt/pull/42264
.. _`#42267`: https://github.com/saltstack/salt/issues/42267
.. _`#42269`: https://github.com/saltstack/salt/pull/42269
.. _`#42275`: https://github.com/saltstack/salt/pull/42275
.. _`#42279`: https://github.com/saltstack/salt/issues/42279
.. _`#42282`: https://github.com/saltstack/salt/pull/42282
.. _`#42289`: https://github.com/saltstack/salt/pull/42289
.. _`#42291`: https://github.com/saltstack/salt/pull/42291
.. _`#42295`: https://github.com/saltstack/salt/issues/42295
.. _`#42308`: https://github.com/saltstack/salt/pull/42308
.. _`#42314`: https://github.com/saltstack/salt/pull/42314
.. _`#42319`: https://github.com/saltstack/salt/pull/42319
.. _`#42329`: https://github.com/saltstack/salt/issues/42329
.. _`#42333`: https://github.com/saltstack/salt/issues/42333
.. _`#42339`: https://github.com/saltstack/salt/pull/42339
.. _`#42350`: https://github.com/saltstack/salt/pull/42350
.. _`#42352`: https://github.com/saltstack/salt/pull/42352
.. _`#42353`: https://github.com/saltstack/salt/pull/42353
.. _`#42356`: https://github.com/saltstack/salt/pull/42356
.. _`#42357`: https://github.com/saltstack/salt/issues/42357
.. _`#42359`: https://github.com/saltstack/salt/pull/42359
.. _`#42360`: https://github.com/saltstack/salt/pull/42360
.. _`#42368`: https://github.com/saltstack/salt/pull/42368
.. _`#42370`: https://github.com/saltstack/salt/pull/42370
.. _`#42371`: https://github.com/saltstack/salt/issues/42371
.. _`#42375`: https://github.com/saltstack/salt/issues/42375
.. _`#42387`: https://github.com/saltstack/salt/pull/42387
.. _`#42403`: https://github.com/saltstack/salt/issues/42403
.. _`#42405`: https://github.com/saltstack/salt/issues/42405
.. _`#42413`: https://github.com/saltstack/salt/issues/42413
.. _`#42414`: https://github.com/saltstack/salt/pull/42414
.. _`#42417`: https://github.com/saltstack/salt/issues/42417
.. _`#42424`: https://github.com/saltstack/salt/pull/42424
.. _`#42433`: https://github.com/saltstack/salt/pull/42433
.. _`#42443`: https://github.com/saltstack/salt/pull/42443
.. _`#42456`: https://github.com/saltstack/salt/issues/42456
.. _`#42464`: https://github.com/saltstack/salt/pull/42464
.. _`#42477`: https://github.com/saltstack/salt/issues/42477
.. _`#42479`: https://github.com/saltstack/salt/pull/42479
.. _`#42509`: https://github.com/saltstack/salt/pull/42509
.. _`#42515`: https://github.com/saltstack/salt/pull/42515
.. _`#42516`: https://github.com/saltstack/salt/pull/42516
.. _`#42523`: https://github.com/saltstack/salt/pull/42523
.. _`#42527`: https://github.com/saltstack/salt/pull/42527
.. _`#42547`: https://github.com/saltstack/salt/pull/42547
.. _`#42551`: https://github.com/saltstack/salt/pull/42551
.. _`#42552`: https://github.com/saltstack/salt/pull/42552
.. _`#42571`: https://github.com/saltstack/salt/pull/42571
.. _`#42573`: https://github.com/saltstack/salt/pull/42573
.. _`#42574`: https://github.com/saltstack/salt/pull/42574
.. _`#42586`: https://github.com/saltstack/salt/pull/42586
.. _`#42600`: https://github.com/saltstack/salt/issues/42600
.. _`#42623`: https://github.com/saltstack/salt/pull/42623
.. _`#42627`: https://github.com/saltstack/salt/issues/42627
.. _`#42629`: https://github.com/saltstack/salt/pull/42629
.. _`#42642`: https://github.com/saltstack/salt/issues/42642
.. _`#42644`: https://github.com/saltstack/salt/issues/42644
.. _`#42651`: https://github.com/saltstack/salt/pull/42651
.. _`#42655`: https://github.com/saltstack/salt/pull/42655
.. _`#42663`: https://github.com/saltstack/salt/pull/42663
.. _`#42669`: https://github.com/saltstack/salt/pull/42669
.. _`#42683`: https://github.com/saltstack/salt/issues/42683
.. _`#42686`: https://github.com/saltstack/salt/issues/42686
.. _`#42690`: https://github.com/saltstack/salt/issues/42690
.. _`#42693`: https://github.com/saltstack/salt/pull/42693
.. _`#42694`: https://github.com/saltstack/salt/pull/42694
.. _`#42731`: https://github.com/saltstack/salt/issues/42731
.. _`#42744`: https://github.com/saltstack/salt/pull/42744
.. _`#42747`: https://github.com/saltstack/salt/issues/42747
.. _`#42748`: https://github.com/saltstack/salt/pull/42748
.. _`#42753`: https://github.com/saltstack/salt/issues/42753
.. _`#42760`: https://github.com/saltstack/salt/pull/42760
.. _`#42764`: https://github.com/saltstack/salt/pull/42764
.. _`#42784`: https://github.com/saltstack/salt/pull/42784
.. _`#42786`: https://github.com/saltstack/salt/pull/42786
.. _`#42788`: https://github.com/saltstack/salt/pull/42788
.. _`#42795`: https://github.com/saltstack/salt/pull/42795
.. _`#42798`: https://github.com/saltstack/salt/pull/42798
.. _`#42803`: https://github.com/saltstack/salt/issues/42803
.. _`#42804`: https://github.com/saltstack/salt/pull/42804
.. _`#42805`: https://github.com/saltstack/salt/pull/42805
.. _`#42806`: https://github.com/saltstack/salt/pull/42806
.. _`#42826`: https://github.com/saltstack/salt/pull/42826
.. _`#42829`: https://github.com/saltstack/salt/pull/42829
.. _`#42835`: https://github.com/saltstack/salt/pull/42835
.. _`#42836`: https://github.com/saltstack/salt/pull/42836
.. _`#42838`: https://github.com/saltstack/salt/pull/42838
.. _`#42848`: https://github.com/saltstack/salt/pull/42848
.. _`#42851`: https://github.com/saltstack/salt/pull/42851
.. _`#42856`: https://github.com/saltstack/salt/pull/42856
.. _`#42859`: https://github.com/saltstack/salt/pull/42859
.. _`#42861`: https://github.com/saltstack/salt/pull/42861
.. _`#42864`: https://github.com/saltstack/salt/pull/42864
.. _`#42869`: https://github.com/saltstack/salt/issues/42869
.. _`#42871`: https://github.com/saltstack/salt/pull/42871
.. _`#42877`: https://github.com/saltstack/salt/pull/42877
.. _`#42882`: https://github.com/saltstack/salt/pull/42882
.. _`#42883`: https://github.com/saltstack/salt/pull/42883
.. _`#42886`: https://github.com/saltstack/salt/pull/42886
.. _`#42890`: https://github.com/saltstack/salt/pull/42890
.. _`#42918`: https://github.com/saltstack/salt/pull/42918
.. _`#42919`: https://github.com/saltstack/salt/pull/42919
.. _`#42940`: https://github.com/saltstack/salt/pull/42940
.. _`#42942`: https://github.com/saltstack/salt/pull/42942
.. _`#42944`: https://github.com/saltstack/salt/pull/42944
.. _`#42949`: https://github.com/saltstack/salt/pull/42949
.. _`#42950`: https://github.com/saltstack/salt/pull/42950
.. _`#42952`: https://github.com/saltstack/salt/pull/42952
.. _`#42954`: https://github.com/saltstack/salt/pull/42954
.. _`#42959`: https://github.com/saltstack/salt/pull/42959
.. _`#42968`: https://github.com/saltstack/salt/pull/42968
.. _`#42969`: https://github.com/saltstack/salt/pull/42969
.. _`#42985`: https://github.com/saltstack/salt/pull/42985
.. _`#42986`: https://github.com/saltstack/salt/pull/42986
.. _`#42992`: https://github.com/saltstack/salt/issues/42992
.. _`#43009`: https://github.com/saltstack/salt/pull/43009
.. _`#43014`: https://github.com/saltstack/salt/pull/43014
.. _`#43019`: https://github.com/saltstack/salt/pull/43019
.. _`#43020`: https://github.com/saltstack/salt/pull/43020
.. _`#43021`: https://github.com/saltstack/salt/pull/43021
.. _`#43023`: https://github.com/saltstack/salt/pull/43023
.. _`#43026`: https://github.com/saltstack/salt/pull/43026
.. _`#43027`: https://github.com/saltstack/salt/pull/43027
.. _`#43031`: https://github.com/saltstack/salt/pull/43031
.. _`#43032`: https://github.com/saltstack/salt/pull/43032
.. _`#43033`: https://github.com/saltstack/salt/pull/43033
.. _`#43036`: https://github.com/saltstack/salt/issues/43036
.. _`#43037`: https://github.com/saltstack/salt/pull/43037
.. _`#43048`: https://github.com/saltstack/salt/pull/43048
.. _`#43054`: https://github.com/saltstack/salt/pull/43054
.. _`#43060`: https://github.com/saltstack/salt/pull/43060
.. _`#43064`: https://github.com/saltstack/salt/pull/43064
.. _`#43092`: https://github.com/saltstack/salt/pull/43092
.. _`#43100`: https://github.com/saltstack/salt/pull/43100
.. _`#43101`: https://github.com/saltstack/salt/issues/43101
.. _`#43103`: https://github.com/saltstack/salt/pull/43103
.. _`#43116`: https://github.com/saltstack/salt/pull/43116
.. _`#43143`: https://github.com/saltstack/salt/issues/43143
.. _`#43151`: https://github.com/saltstack/salt/pull/43151
.. _`#43154`: https://github.com/saltstack/salt/pull/43154
.. _`#43171`: https://github.com/saltstack/salt/pull/43171
.. _`#43173`: https://github.com/saltstack/salt/pull/43173
.. _`#43178`: https://github.com/saltstack/salt/pull/43178
.. _`#43179`: https://github.com/saltstack/salt/pull/43179
.. _`#43191`: https://github.com/saltstack/salt/pull/43191
.. _`#43196`: https://github.com/saltstack/salt/pull/43196
.. _`#43198`: https://github.com/saltstack/salt/issues/43198
.. _`#43199`: https://github.com/saltstack/salt/pull/43199
.. _`#43202`: https://github.com/saltstack/salt/pull/43202
.. _`#43228`: https://github.com/saltstack/salt/pull/43228
.. _`#43271`: https://github.com/saltstack/salt/pull/43271
.. _`#475`: https://github.com/saltstack/salt/issues/475
.. _`#495`: https://github.com/saltstack/salt/issues/495
.. _`bp-37424`: https://github.com/saltstack/salt/pull/37424
.. _`bp-39366`: https://github.com/saltstack/salt/pull/39366
.. _`bp-41543`: https://github.com/saltstack/salt/pull/41543
.. _`bp-41780`: https://github.com/saltstack/salt/pull/41780
.. _`bp-41820`: https://github.com/saltstack/salt/pull/41820
.. _`bp-42097`: https://github.com/saltstack/salt/pull/42097
.. _`bp-42098`: https://github.com/saltstack/salt/pull/42098
.. _`bp-42109`: https://github.com/saltstack/salt/pull/42109
.. _`bp-42224`: https://github.com/saltstack/salt/pull/42224
.. _`bp-42433`: https://github.com/saltstack/salt/pull/42433
.. _`bp-42547`: https://github.com/saltstack/salt/pull/42547
.. _`bp-42552`: https://github.com/saltstack/salt/pull/42552
.. _`bp-42651`: https://github.com/saltstack/salt/pull/42651
.. _`bp-42744`: https://github.com/saltstack/salt/pull/42744
.. _`bp-42760`: https://github.com/saltstack/salt/pull/42760
.. _`bp-42784`: https://github.com/saltstack/salt/pull/42784
.. _`bp-42848`: https://github.com/saltstack/salt/pull/42848
.. _`bp-42871`: https://github.com/saltstack/salt/pull/42871
.. _`bp-42883`: https://github.com/saltstack/salt/pull/42883
.. _`bp-43020`: https://github.com/saltstack/salt/pull/43020
.. _`bp-43031`: https://github.com/saltstack/salt/pull/43031
.. _`bp-43116`: https://github.com/saltstack/salt/pull/43116
.. _`fix-38839`: https://github.com/saltstack/salt/issues/38839
.. _`fix-41116`: https://github.com/saltstack/salt/issues/41116
.. _`fix-41721`: https://github.com/saltstack/salt/issues/41721
.. _`fix-41885`: https://github.com/saltstack/salt/issues/41885
.. _`fix-42115`: https://github.com/saltstack/salt/issues/42115
.. _`fix-42152`: https://github.com/saltstack/salt/issues/42152
.. _`fix-42267`: https://github.com/saltstack/salt/issues/42267
.. _`fix-42375`: https://github.com/saltstack/salt/issues/42375
.. _`fix-42405`: https://github.com/saltstack/salt/issues/42405
.. _`fix-42417`: https://github.com/saltstack/salt/issues/42417
.. _`fix-42683`: https://github.com/saltstack/salt/issues/42683
